@@ -77,6 +77,44 @@ class _Trochoid(ABC):
         self.y += self.origin[1]
         self.coords = list(zip(self.x, self.y, self.thetas))
 
+    def transform(self, x: Number = 0, y: Number = 0) -> "_Trochoid":
+        """
+        Return a new shape translated by the given x and y offsets.
+
+        Parameters
+        ----------
+        x : Number, optional, default=0
+            The x-offset to shift the shape by.
+        y : Number, optional, default=0
+            The y-offset to shift the shape by.
+
+        Returns
+        -------
+        _Trochoid
+            A new instance of the shape translated by the given x and y offsets.
+
+        Examples
+        --------
+        >>> shape = Trochoid(R=5, r=2, d=3, thetas=thetas)
+        >>> transformed_shape = shape.transform(x=10, y=5)
+        """
+        try:
+            transformed_shape = self.__class__(
+                R=self.R,
+                r=self.r,
+                d=self.d,
+                thetas=self.thetas,
+                origin=(self.origin[0]+x, self.origin[1]+y)
+            )
+        except TypeError:
+            transformed_shape = self.__class__(
+                R=self.R,
+                r=self.r,
+                thetas=self.thetas,
+                origin=(self.origin[0]+x, self.origin[1]+y)
+            )
+        return transformed_shape
+
     def scale(self, factor: Number) -> Union["_Trochoid", "_Cycloid"]:
         """Return shape with input parameters scaled by a given input factor.
 
